from typing import Any

from stripe import api_requestor as api_requestor

def nested_resource_class_methods(
    resource, path: Any | None = ..., operations: Any | None = ..., resource_plural: Any | None = ...
): ...
